Sprite class

Constructors

Sprite({required Texture texture, ScalingMode scalingMode = ScalingMode.containX, Vector2? position, double? rotation, double? scale, Vector2? size, Color? color})

Properties

color ↔ Color
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ Vector2
getter/setter pair
rotation ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ double
getter/setter pair
scos → double
no setter
size ← Vector2
no getter
ssin → double
no setter
texture → Texture
final
transform → RSTransform
no setter
tx → double
no setter
ty → double
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited